package org.eclipse.jdt.internal.compiler.apt.dispatch;

package .tmp;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import javax.annotation.processing.Filer;
import javax.annotation.processing.Messager;
import javax.annotation.processing.ProcessingEnvironment;
import javax.lang.model.SourceVersion;
import javax.lang.model.util.Elements;
import javax.lang.model.util.Types;
import org.eclipse.jdt.internal.compiler.Compiler;
import org.eclipse.jdt.internal.compiler.apt.model.ElementsImpl;
import org.eclipse.jdt.internal.compiler.apt.model.Factory;
import org.eclipse.jdt.internal.compiler.apt.model.TypesImpl;
import org.eclipse.jdt.internal.compiler.env.ICompilationUnit;
import org.eclipse.jdt.internal.compiler.lookup.LookupEnvironment;
import org.eclipse.jdt.internal.compiler.lookup.ReferenceBinding;

public abstract class BaseProcessingEnvImpl implements ProcessingEnvironment {
  private List<ICompilationUnit> _addedUnits = new ArrayList<>();
  
  private List<ReferenceBinding> _addedClassFiles = new ArrayList<>();
  
  private List<ICompilationUnit> _deletedUnits = new ArrayList<>();
  
  protected Elements _elementUtils = (Elements)new ElementsImpl(this);
  
  protected Types _typeUtils = (Types)new TypesImpl(this);
  
  private Factory _factory = new Factory(this);
  
  private boolean _errorRaised = false;
  
  protected Filer _filer;
  
  protected Messager _messager;
  
  protected Map<String, String> _processorOptions;
  
  protected Compiler _compiler;
  
  public void addNewUnit(ICompilationUnit unit) {
    this._addedUnits.add(unit);
  }
  
  public void addNewClassFile(ReferenceBinding binding) {
    this._addedClassFiles.add(binding);
  }
  
  public Compiler getCompiler() {
    return this._compiler;
  }
  
  public ICompilationUnit[] getDeletedUnits() {
    ICompilationUnit[] result = new ICompilationUnit[this._deletedUnits.size()];
    this._deletedUnits.toArray(result);
    return result;
  }
  
  public ICompilationUnit[] getNewUnits() {
    ICompilationUnit[] result = new ICompilationUnit[this._addedUnits.size()];
    this._addedUnits.toArray(result);
    return result;
  }
  
  public Elements getElementUtils() {
    return this._elementUtils;
  }
  
  public Filer getFiler() {
    return this._filer;
  }
  
  public Messager getMessager() {
    return this._messager;
  }
  
  public Map<String, String> getOptions() {
    return this._processorOptions;
  }
  
  public Types getTypeUtils() {
    return this._typeUtils;
  }
  
  public LookupEnvironment getLookupEnvironment() {
    return this._compiler.lookupEnvironment;
  }
  
  public SourceVersion getSourceVersion() {
    if (this._compiler.options.sourceLevel <= 3211264L)
      return SourceVersion.RELEASE_5; 
    if (this._compiler.options.sourceLevel == 3276800L)
      return SourceVersion.RELEASE_6; 
    try {
      return SourceVersion.valueOf("RELEASE_7");
    } catch (IllegalArgumentException illegalArgumentException) {
      return SourceVersion.RELEASE_6;
    } 
  }
  
  public void reset() {
    this._addedUnits.clear();
    this._addedClassFiles.clear();
    this._deletedUnits.clear();
  }
  
  public boolean errorRaised() {
    return this._errorRaised;
  }
  
  public void setErrorRaised(boolean b) {
    this._errorRaised = true;
  }
  
  public Factory getFactory() {
    return this._factory;
  }
  
  public ReferenceBinding[] getNewClassFiles() {
    ReferenceBinding[] result = new ReferenceBinding[this._addedClassFiles.size()];
    this._addedClassFiles.toArray(result);
    return result;
  }
}
